==> evolutility-server-node-1.1.0.tgz: package/models/data/test/test-data.js <==
module.exports = [ 
    {
        "id": 1,
        "parent": 1,
        "name": "Abcdef",
        "text": "ABCDEF",
        "textmultiline": "ABCDEF",
        "lov": 2,
        "lovlc": 5,
        "date": "2019-01-01",
        "datetime": null,
        "time": null,
        "integer": 1,
        "decimal": 1.618,
        "money": "$100.00",
        "boolean": false,
        "email": "abc@abc.com",
        "url": "http://abc.com",
        "document": "",
        "image": "test/bug.gif"
    },
    {
        "id": 2,
        "parent": 1,
        "name": "efghij",
        "text": "EFGHIJ",
        "textmultiline": "EFGHIJ",
        "lov": 1,
        "lovlc": 1,
        "date": "2019-02-01",
        "datetime": null,
        "time": null,
        "integer": 12,
        "decimal": 12.10,
        "money": "$12.10",
        "boolean": false,
        "email": "efghij@efghij.com",
        "url": "http://efghij.com",
    },
    {
        "id": 3,
        "parent": 1,
        "name": "Long text",
        "text": "Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text",
        "textmultiline": "Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text",
        "lov": 4,
        "lovlc": 5,
        "date": "2019-12-24",
        "datetime": "2019-12-24",
        "time": "",
        "integer": 5,
        "decimal": 5.5,
        "money": "$5.25",
        "boolean": true,
        "email": "long_long_long_long_long_long_long_long_long_email@gmail.com",
        "url": "http://someUrlsAreTooStrangeToRememberITHINKAOEFDJIJDQFSKJRKDLFVJWDFKJJDFKLXDFG.com",
        "document": "",
        "image": ""
    } 
];

==> evolutility-server-node-1.1.1.tgz: package/models/data/test/test-data.js <==
module.exports = [ 
    {
        "id": 1,
        "parent": 1,
        "name": "Abcdef",
        "text": "ABCDEF",
        "textmultiline": "ABCDEF",
        "lov": 2,
        "lovlc": 5,
        "list": [1,2,3],
        "date": "2019-01-01",
        "datetime": null,
        "time": null,
        "integer": 1,
        "decimal": 1.618,
        "money": "$100.00",
        "boolean": false,
        "email": "abc@abc.com",
        "url": "http://abc.com",
        "document": "",
        "image": "test/bug.gif",
        "json": [{"a": 123, "b": "abc"},{"a": 5}],
    },
    {
        "id": 2,
        "parent": 1,
        "name": "efghij",
        "text": "EFGHIJ",
        "textmultiline": "EFGHIJ",
        "lov": 1,
        "lovlc": 1,
        "list": [3,4],
        "date": "2019-02-01",
        "datetime": null,
        "time": null,
        "integer": 12,
        "decimal": 12.10,
        "money": "$12.10",
        "boolean": false,
        "email": "efghij@efghij.com",
        "url": "http://efghij.com",
        "json": {"a": 1, "b": "zzzzzz"},
    },
    {
        "id": 3,
        "parent": 1,
        "name": "Long text",
        "text": "Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text",
        "textmultiline": "Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text Long text",
        "lov": 4,
        "lovlc": 5,
        "list": [3,4],
        "date": "2019-12-24",
        "datetime": "2019-12-24",
        "time": "",
        "integer": 5,
        "decimal": 5.5,
        "money": "$5.25",
        "boolean": true,
        "email": "long_long_long_long_long_long_long_long_long_email@gmail.com",
        "url": "http://someUrlsAreTooStrangeToRememberITHINKAOEFDJIJDQFSKJRKDLFVJWDFKJJDFKLXDFG.com",
        "document": "",
        "image": "",
        "json": {"a": 10, "b": "This is another test."},
    } 
];
